# Discussion

It is well-known that Bayesian analysis allows the uncertainty in parameter estimates to be explicitly modelled, with credibility (probability density) assigned to parameter estimate intervals. The provision of uncertainty can clarify close-to-call situations (e.g. Z-factors close to 0.5) and uncover potential false positives (e.g. large Z-factors close to > 0.5 but with high variance), enabling better decision-making under uncertainty. Other merits and caveats of Bayesian analysis have been treated extensively in the literature as well [@Kruschke:2013jy; @Lin:1999cd], and we do not go further into them here.

Probabilistic programming approaches make Bayesian methods much more accessible than analytical methods [@Salvatier:2015tb]. By leveraging these tools, we are in turn able to make Bayesian methods more generally accessible for the generic researcher working in high throughput measurement. In aid of reproducible science, we have also released an open source command-line program available for analysis of this type of data (#cite: Zenodo), with a guide available in both the supplementary material and in the archived repository. We hope to convey that one contribution of this manuscript is to describe the use of software that makes Bayesian estimation easily accessible to life science researchers, especially groups performing high throughput measurements. Because of probabilistic programming libraries built on top of numerical computation libraries, with a little more software engineering, other generally-usable Bayesian models can be made accessible to the general scientific community.

Kruschke's use of the Students T distribution should cover a majority of scenarios in life science measurement, where the specification of a probabilistic graphical model may be infeasible due to a lack of underlying theory. Naturally, we are assuming that the underlying data constitute a Normal-like distribution, where the measurements are symmetrically centred around some mean; where this assumption is violated, or where a different model is more appropriate (e.g. Poisson counts for sequencing reads), a different model specification ought to be used.

A key issue that has cropped up over the past half decade is the scientific "reproducibility crisis", partly due to erroneous researcher reliance on p-values as a judgement device for "significance" [@Wasserstein:2016jo]. Judgements of what "hits" to continue with downstream processing often relies on a calculated p-value rather than effect sizes; statistical significance has come to replace biological significance [@Nuzzo:2014bp; @Baker:2016hd]. In light of this, we argue that by taking a Bayesian view of the data, we may replace p-value-based judgement calls with ones based on the distribution and uncertainty in estimated quality evaluation parameters (e.g. Z-factors & effect sizes), hence improving the quality of published results in the scientific literature.
