# Results

## Statistically Defensible Replicate Measurements

In order to investigate how the number of replicates affected the accuracy, we simulated experimental runs of 100 samples with varying numbers replicate measurements (`n=2` to `n=20`). For each `n`, 20 experimental runs were simulated. Accuracy was measured as the fraction of estimated 95% highest posterior densities (HPDs) that contained the true mean.

As shown in Figure @fig:accuracy, the baseline accuracy rate with duplicate (`n=2`) measurements, as measured by fraction of actual values inside the posterior density's 95% HPD, falls around the 70-75% range. This means that about 25% of the final posterior 95% HPDs do not encompass the actual value. By contrast, by using `n=5` replicates, the accurate HPD fraction falls around the 85-90% range. Roughly doubling the number of samples decreases the inaccurate fraction by up to 3-fold. Following the law of diminishing marginal returns, additional accuracy can be gained, but at a cost of increasing sample sizes.

![Accuracy of 95% HPD as a function of number of replicate samples taken.](./figures/accuracy.pdf){#fig:accuracy}

## Representation of Uncertainty

Statistical software (e.g. GraphPad Prism) make it easy for researchers to visualize and compute frequentist confidence intervals and error bars. However, as a result of their ease of use, it is also easy to make statistical errors such as reporting error bars using the standard error of the mean (SEM), rather than 95% confidence/credible intervals. Our analysis of simulation and experimental data show clearly what can be inferred from the mathematical form but is often ignored: that the SEM grossly under-represents the uncertainty in measurement and data variation compared to 95% confidence intervals and Bayesian 95% credible intervals (Figure @fig:range-estimates). The SEM also provides the standard deviation of the sampling distribution of the mean, and not the uncertainty in our measurement of the mean. As such, it would be poor statistical practice to report SEM, and Bayesian 95% credible intervals would be a much better choice.

![Bayesian 95% credible interval, Frequentist 95% confidence interval, and SEM interval widths as compared to the actual data range. (left) Simulated data. (right) Experimental measurement data measuring the influence of heat-killed bacteria on influenza activity.](./figures/range-estimates.png){#fig:range-estimates}

## Posterior Densities of Assay Parameters

Statistical parameters, such as the Z-factor, have been developed to evaluate the quality of HT assay data [@Zhang:1999fr; @Sui:2007dc]; these are akin to the calculation of effect sizes, which can also be computed. By taking a Bayesian view, we can compute not just the expected parameter values but also their posterior distributions (Figure @fig:z-factor), in the same way as distributions of effect sizes can be deterministically computed [@Kruschke:2013jy].

Taking Z-factors as an example, given the uncertainty surrounding simulated measurements, the original 3-class system for classifying the quality of an hit can be extended to 5 classes (Figure @fig:z-factor). The original 3-class system was "large separation" (Z-factor ≥ 0.5), "small separation" (0 < Z-factor < 0.5) and indistinguishable from noise (Z-factor < 0). With a Bayesian view of the data, we can assign credibility to the Z-factor scores, hence allowing for "probable large separation" and "probable small separation" to be added in, which may be of most practical interest in screening experiments.

![Z-score classes and simulation data. Circle/dot: HPD mean. Thick lines: HPD inter-quartile range. Thin lines: 95% HPD range. (a) Five Z-score classes based on the Z-score posterior density. (b) Forest plot of posterior distributions from one simulation run. Samples 11 and 12 (respectively) are the blank and the non-extreme positive control in this simulated experiment. (top-left) Posterior density in fold change relative to blank. (top-right) Posterior density of variance. (bottom-left) Deterministic posterior density of fold change relative to positive control. (bottom-right) Deterministic posterior density of Z-factor computed using the non-extreme positive control as the baseline.](./figures/z-factor.png){#fig:z-factor}

The actionable consequences of these Z-value distributions depends on the experimental context. There may be scenarios where downstream experimentation is expensive, and only "true hits" should be tested; in this case, the "probable large separation" samples may be chosen for exclusion, helping to reduce costs. On the other hand, if downstream experimentation is cheap, and it is desirable to have a large set of samples to be processed further, then samples in the "probable small separation" may be included in downstream testing, helping to reduce false negatives. Here, the advantages of Bayesian analysis shines through: the uncertainty in measurement has actionable consequences. At the same time, the truism remains: statistics does not replace human judgment of the value of a sample, but can serve as a valuable tool in the decision-making process.

We note that Z-factors are not the only statistical parameters that can be computed. Other deterministically calculated parameters, such as effect sizes, can be computed in a similar fashion, likewise yielding uncertainty estimates, given the data.
