# # Introduction

High throughput (HT) screening experiments are necessary for systematically interrogating biology. However, there are a number of statistical issues that are widespread in the HT screening literature. Firstly, triplicate (or worse, duplicate) measurements are commonplace, with little statistical justification; conceivably, the choice to test as few replicates as possible is most likely cost driven, which is a pragmatic reason but nonetheless detrimental for scientific accuracy. Secondly, t-tests with multiple hypothesis correction serves as the main vehicle for statistical analysis of HT data; multiple hypothesis correction potentially leads to falsely identifying samples as negatives or non-hits. Thirdly, standard error of the mean (SEM) are commonly used as the reported error bars, not only in the HT literature but also in non-HT publications [@Kemnitzer:2005cr; @Marion:2009cm; @LeHellard:2002ht; @Fu:2014jl], and this under-represents the variation in the data, thereby misleading readers. Finally, statistical parameters for assay evaluation are computed without acknowledging the uncertainty that may arise because of uncertainty in the data.

As outlined by Kruschke [@Kruschke:2013jy], Bayesian estimation offers a way out of the statistical issues above. To address these problems, we use probabilistic programming to extend Kruschke's two-sample comparison model [@Kruschke:2013jy] to a 'generic' HT assay (Figure @fig:pgm, Supplementary Text). Kruschke's two-sample comparison model is appropriate for scenarios where there is little underlying theory that can be used to mechanistically model the data-generation process, and only the final data being measured (fold change, percentage activity, etc.) is of interest. It is also extensible to multiple treatment scenarios, where each treatment is experimentally independent of each other (i.e. the effect of treatment B is not dependent on treatment A, because of physical isolation). Using this "generic" model, we are able to simultaneously provide Bayesian posterior distributions of measurement and statistical evaluation parameters.

To address the question of what is a "good" sample size (i.e. number of replicate measurements), we use simulations to show that 5 replicate measurements are sufficient to drastically reduce measurement inaccuracy while balancing cost of experimentation, when compared to the current standard of 2-3 replicate measurements. Using both simulation and real data, we show that the common practice of reporting mean ± SEM under-represents the uncertainty in measurement variation. We then argue that knowing the uncertainty in statistical assessment parameters can help guide rational decision-making, such as deciding what hits to pursue. Finally, we provide a command-line program with documentation for end-users with little programming experience.

![Bayesian hierarchical model.](./figures/pgm.png){#fig:pgm}